<!--

// Verifies an IP address

function verifyIP (ipValue, theName, required) 
{
    var errorString = "";

    var ipPattern = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/;
    var ipArray = ipValue.match(ipPattern); 

    // Some fields do not require that an IP address be entered
    if (ipValue == "")
    {
        if (required)
        {
          alert(theName + ': required field.');
          return false;
        }
        else
          return true;
    }
    
    // Check for special cases
    if (ipValue == "0.0.0.0")
        errorString = theName + ': '+ipValue+' is a special IP address and cannot be used.';
    else if (ipValue == "255.255.255.255")
        errorString = theName + ': '+ipValue+' is a special IP address and cannot be used.';
    else if (ipArray == null)
    {
        errorString = theName + ': '+ipValue+' is not a valid IP address.';
    }
    else 
    {
        for (i = 1; i <= 4; i++) 
        {
            thisSegment = ipArray[i];
            if (thisSegment > 255) 
            {
                errorString = theName + ': '+ipValue+' is not a valid IP address.';
                i = 4;
            }
        }
    }
    if (errorString == "")
    {
        return true;
    }
    else
    {
        alert (errorString);
        return false;
    }
}  // verifyIP


// Verifies IP address, or a range of IP addresses, see regular expression below

function verifyIPRange(ipValue, theName, required)
{
    var ipPattern = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})(:(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3}))?$/;
    var ipArray = ipValue.match(ipPattern); 

    // Some fields do not require that an IP address be entered
    if (ipValue == "")
    {
        if (required)
        {
            alert(theName + ': required field.');
            return false;
        }
        else
            return true;
    }
    
    // Check for special cases
    if (ipValue == "0.0.0.0")
    {
        alert(theName + ': '+ipValue+' is a special IP address and cannot be used.');
        return false;
    }
    if (ipValue == "255.255.255.255")
    {
        alert(theName + ': '+ipValue+' is a special IP address and cannot be used.');
        return false;
    }
    if (ipArray == null)
    {
        alert(theName + ': '+ipValue+' is not a valid IP address or IP address range.\nAn IP address range is two IP addresses separated by a colon.');
        return false;
    }
    for (i = 1; i <= ipArray.length; i++) 
    {
        thisSegment = ipArray[i];
        if (thisSegment && thisSegment > 255) 
        {
            alert(theName + ': '+ipValue+' is not a valid IP address or IP address range.\nAn IP address range is two IP addresses separated by a colon.');
            return false;
        }
    }
    return true;
}  // verifyIPRange


// Verifies an IPv6 address

function verifyIPv6 (ipValue, theName, required, prefix) 
{
    var ipPattern;
    var ipv4Pattern = /^(0{0,4})\:((0{0,4}\:){0,4})(0{0,4})\:(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})\/(\d{1,3})$/;
    var ipArray;

    // Some fields do not require that an IP address be entered
    if (ipValue == "" && required)
    {
        alert(theName + ': required field.');
        return false;
    }
    if (ipValue == "" && !required)
        return true;
    
    var ipv4Array = ipValue.match(ipv4Pattern); 

    if (prefix)
      ipPattern = /^([0-9a-fA-F]{0,4})\:(([0-9a-fA-F]{0,4}\:){0,5})([0-9a-fA-F]{0,4})\:([0-9a-fA-F]{1,4})\/(\d{1,3})$/;
    else
      ipPattern = /^([0-9a-fA-F]{0,4})\:(([0-9a-fA-F]{0,4}\:){0,5})([0-9a-fA-F]{0,4})\:([0-9a-fA-F]{1,4})$/;
    ipArray = ipValue.match(ipPattern); 

    if (ipArray == null && ipv4Array == null)
    {
        if (prefix)
          alert(theName + ': invalid IPv6 address.\nThe IP address format is up to 8 hexidecimal numbers separated by a colon,\nfollowed by a slash and the prefix (subnet mask).');
        else
          alert(theName + ': invalid IPv6 address.\nThe IP address format is up to 8 hexidecimal numbers separated by a colon.');
        return false;
    }

    if (prefix && ipArray != null && ipArray[ipArray.length-1] > 128)
    {
        alert(theName + ': invalid IPv6 address.\nThe prefix (subnet mask) must be in the range 0-128.');
        return false;
    }
    if (ipv4Array != null)
    {
        for ( i=ipv4Array.length-5 ; i<=ipv4Array.length-2 ; i++ )
        {
            if (ipv4Array[i] > 255)
            {
                alert(theName + ": invalid IPv6 address.\nEach number in the IPv4 portion of the address must be less than 256.");
                return false;
            }
        }
    }

    // Check for special cases??

    return true;
}  // verifyIPv6


// Verifies a subnet mask

function verifyMask (ipValue, theName, required) 
{
    errorString = "";

    var ipPattern = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/;
    var ipArray = ipValue.match(ipPattern); 

    // Some fields do not require that a mask be entered
    if (ipValue == "")
    {
        if (required)
        {
          alert(theName + ': required field.');
          return false;
        }
        else
          return true;
    }
    
    if (ipArray == null)
    {
        errorString = theName + ': '+ipValue+' is not a valid network mask.';
    }
    else 
    {
        for (i = 1; i <= 4; i++) 
        {
            thisSegment = ipArray[i];
            if (thisSegment > 255) 
            {
                errorString = theName + ': '+ipValue+' is not a valid network mask.';
                i = 4;
            }
        }
    }
    if (errorString == "")
    {
        return true;
    }
    else
    {
        alert (errorString);
        return false;
    }
}  // verifyMask


// Verifies one or more subnets in CIDR (xxx.xxx.xxx.xxx/xx) notation

function verifyCIDR (ipValue, theName, required) 
{
    var ipPattern = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})\/(\d{1,2})(\,(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})\/(\d{1,2}))*$/;
    var ipArray = ipValue.match(ipPattern); 

    // Some fields do not require that a value be entered
    if (ipValue == "")
    {
        if (required)
        {
          alert(theName + ': required field.');
          return false;
        }
        else
          return true;
    }
    
    if (ipArray == null)
    {
        alert(theName + ': '+ipValue+' is not a valid list of subnets.\nA valid list subnets is one or more subnets in CIDR notation\n(IP Address/Mask Bits), with a comma separating each subnet.');
        return false;
    }
    for (i = 1; i <= ipArray.length; i++) 
    {
        thisSegment = ipArray[i];
        if (i % 5 == 0)
        {
            if (thisSegment && thisSegment > 32) 
            {
                alert(theName + ': '+ipValue+' is not a valid list of subnets.\nA valid list subnets is one or more subnets in CIDR notation\n(IP Address/Mask Bits), with a comma separating each subnet.');
                return false;
            }
        }
        else
        {
            if (thisSegment && thisSegment > 255) 
            {
                alert(theName + ': '+ipValue+' is not a valid list of subnets.\nA valid list subnets is one or more subnets in CIDR notation\n(IP Address/Mask Bits), with a comma separating each subnet.');
                return false;
            }
        }
    }
    return true;
}  // verifyCIDR


// Verifies an IP address and optional mask bits (xxx.xxx.xxx.xxx/xx) 

function verifyIPandMaskBits (ipValue, theName, required, maskOpt) 
{
    var ipPattern = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})(\/(\d{1,2}))?$/;
    var ipArray = ipValue.match(ipPattern); 

    // Some fields do not require that a value be entered
    if (ipValue == "")
    {
        if (required)
        {
          alert(theName + ': required field.');
          return false;
        }
        else
          return true;
    }
    
    if (ipArray == null)
    {
        alert(theName + ': '+ipValue+' is not a valid IP Address/Netmask Bits.\nThe Netmask Bits is optional and must be 0 - 32.');
        return false;
    }
    for (i = 1; i <= ipArray.length; i++) 
    {
        thisSegment = ipArray[i];
        if (i == 6)
        {
            if (thisSegment && thisSegment > 32) 
            {
                alert(theName + ': '+ipValue+' is not a valid IP Address/Netmask Bits.\nThe Netmask Bits is optional and must be 0 - 32.');
                return false;
            }
        }
        else
        {
            if (thisSegment && thisSegment > 255) 
            {
                alert(theName + ': '+ipValue+' is not a valid IP Address/Netmask Bits.\nThe Netmask Bits is optional and must be 0 - 32.');
                return false;
            }
        }
    }
    return true;
}  // verifyIPandMaskBits


// Verifies a hostname, see comments below for valid pattern
// The name can be any name - a short name, or a FQDN

function verifyName(nValue, theName, fqdnOK, required)
{
    errorString = "";

    // Some fields do not require that a hostname be entered
    if (nValue == "")
    {
        if (required)
        {
            alert(theName + ': required field.');
            return false;
        }
        else
            return true;
    }
    
    // looks for 
    // 1) a short name first - any sequence of alphanumeric, _ and -, must
    //    start with a digit or letter
    // 2) a fully qualified domain name:
    //    a) one or more series of: any sequence of alphanumeric, _ and -, 
    //       must start with a digit or letter, followed by a period
    //    b) followed by 2-4 alpha chars
    if (/^[a-zA-Z0-9][\w\-]+$/.test(nValue))
    {
        // short name
        return true;
    }
    if (fqdnOK)
    {
        if (/^(([a-zA-Z0-9][\w\-]+)\.)+([a-zA-Z]{2,6})$/.test(nValue))
        {
            // FQDN
            return true;
        }
        errorString = theName + ': '+nValue+' is not a valid name.\nThe name must be either a short name ("myhost")\nor a fully qualified domain name ("myhost.domain.com").';
        alert(errorString);
        return false;
    }
    else
    {
        errorString = theName + ': '+nValue+' is not a valid name.\nThe name must be a short name ("myhost").\nValid characters are digits, letters, \'-\' and \'_\', and must start with a digit or letter.';
        alert(errorString);
        return false;
    }
}  // verifyName


// Verifies a fully qualified domain/host name, 
// see comments below for valid pattern

function verifyFQDN(nValue, theName, required)
{
    errorString = "";

    // Some fields do not require that a hostname be entered
    if (nValue == "")
    {
        if (required)
        {
          alert(theName + ': required field.');
          return false;
        }
        else
          return true;
    }
    
    // looks for a fully qualified domain name:
    // 1) one or more series of: any sequence of alphanumeric, _ and -, 
    //    followed by a period
    // 2) followed by 2-4 alpha chars
    if (/^(([\w\-]+)\.)+([a-zA-Z]{2,6})$/.test(nValue))
    {
        return true;
    }
    // hack alert - tweak error message for NIS Domain
    if (theName == "NIS Domain")
      errorString = theName + ': '+nValue+' is not a valid name.\nThe name must be a fully qualified domain name ("domain.com").';
    else
      errorString = theName + ': '+nValue+' is not a valid name.\nThe name must be a fully qualified domain name ("myhost.domain.com").';
    alert(errorString);
    return false;
}  // verifyFQDN


// Verifies a hostname or IP address, see comments below for valid pattern
// The name can be any name - a short name, or a FQDN

function verifyNameOrIP(nValue, theName, required)
{
    var errorString = "";
    var ipPattern = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/;
    var ipArray = nValue.match(ipPattern); 

    // Some fields do not require that a hostname or IP address be entered
    if (nValue == "")
    {
        if (required)
        {
          alert(theName + ': required field.');
          return false;
        }
        else
          return true;
    }
    
    // Check for special cases
    if (nValue == "0.0.0.0")
        errorString = theName + ': '+nValue+' is a special IP address and cannot be used.';
    else if (nValue == "255.255.255.255")
        errorString = theName + ': '+nValue+' is a special IP address and cannot be used.';
    else if (ipArray == null)
    {
        errorString = theName + ': '+nValue+' is not a valid IP address.';
    }
    else 
    {
        for (i = 1; i <= 4; i++) 
        {
            thisSegment = ipArray[i];
            if (thisSegment > 255) 
            {
                errorString = theName + ': '+nValue+' is not a valid IP address.';
                i = 4;
            }
        }
    }
    if (errorString == "")
    {
        // nValue is a valid IP address
        return true;
    }
    else
    {
        // check for hostname, looks for 
        // 1) a short name first - any sequence of alphanumeric, _ and -
        // 2) a fully qualified domain name:
        //    a) one or more series of: any sequence of alphanumeric, _ and -, 
        //       followed by a period
        //    b) followed by 2-4 alpha chars
        if (/^[\w\-]+$/.test(nValue))
        {
            // short name
            return true;
        }
        if (/^(([\w\-]+)\.)+([a-zA-Z]{2,6})$/.test(nValue))
        {
            // FQDN
            return true;
        }
        errorString = theName + ': '+nValue+' is not a valid name or IP address.\nA name must be either a short name ("myhost")\nor a fully qualified domain name ("myhost.domain.com").';
        alert(errorString);
        return false;
    }
}  // verifyNameOrIP

-->
